@@ -1,18 +1,19 @@
 import logging
 from typing import Dict, Optional
 
-from dynatrace.activegate import ActiveGateService
-from dynatrace.cluster_time import ClusterTimeService
-from dynatrace.custom_device import CustomDeviceService
-from dynatrace.dashboard import DashboardService
-from dynatrace.entity import EntityService
-from dynatrace.event import EventService
-from dynatrace.extension import ExtensionService
+from dynatrace.configuration_v1.dashboard import DashboardService
+from dynatrace.configuration_v1.plugins import PluginService
+from dynatrace.environment_v1.cluster_time import ClusterTimeService
+from dynatrace.environment_v1.custom_device import CustomDeviceService
+from dynatrace.environment_v1.event import EventService
+from dynatrace.environment_v1.synthetic_third_party import ThirdPartySyntheticTestsService
+from dynatrace.environment_v2.activegate import ActiveGateService
+from dynatrace.environment_v2.activegate_autoupdate import ActiveGateAutoUpdateService
+from dynatrace.environment_v2.entity import EntityService
+from dynatrace.environment_v2.extension import ExtensionService
+from dynatrace.environment_v2.metric import MetricService
+from dynatrace.environment_v2.token import TokenService
 from dynatrace.http_client import HttpClient
-from dynatrace.metric import MetricService
-from dynatrace.plugins import PluginService
-from dynatrace.synthetic_third_party import ThirdPartySyntheticTestsService
-from dynatrace.token import TokenService
 
 
 class Dynatrace:
@@ -43,6 +44,7 @@ class Dynatrace:
         )
 
         self.activegates: ActiveGateService = ActiveGateService(self.__http_client)
+        self.activegates_autoupdate: ActiveGateAutoUpdateService = ActiveGateAutoUpdateService(self.__http_client)
         self.cluster_time: ClusterTimeService = ClusterTimeService(self.__http_client)
         self.custom_devices: CustomDeviceService = CustomDeviceService(self.__http_client)
         self.dashboards: DashboardService = DashboardService(self.__http_client)
